@@ -1,18 +1,22 @@
 """
 """
 
+# stdlib
+from datetime import date
+
+# module
 from avwx.current.base import Reports
-from avwx.parsing import core
+from avwx.parsing import sanitization
 from avwx.structs import AirepData
 
 
-def parse(report: str) -> AirepData:
+def parse(report: str, issued: date = None) -> AirepData:
     """
     """
     if not report:
         return None
-    clean = core.sanitize_report_string(report)
-    wxdata = core.sanitize_report_list(clean.split())
+    clean = sanitization.sanitize_report_string(report)
+    wxdata = sanitization.sanitize_report_list(clean.split())
     wxresp = {"raw": report, "sanitized": " ".join(wxdata)}
     print(wxdata)
     print(wxresp)
@@ -36,4 +40,4 @@ class Aireps(Reports):
     def _post_update(self):
         self.data = []
         for report in self.raw:
-            parse(report)
+            parse(report, self.issued)
